@@ -33,9 +33,10 @@
 #  define KITEMMODELS_DEPRECATED_NO_EXPORT KITEMMODELS_NO_EXPORT KITEMMODELS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KITEMMODELS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KITEMMODELS_NO_DEPRECATED
+#    define KITEMMODELS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
